km3pipe.io.PicklePump
=====================

.. currentmodule:: km3pipe.io

.. autoclass:: PicklePump

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~PicklePump.__init__
      ~PicklePump.add
      ~PicklePump.close
      ~PicklePump.close_file
      ~PicklePump.configure
      ~PicklePump.expose
      ~PicklePump.finish
      ~PicklePump.get
      ~PicklePump.get_blob
      ~PicklePump.next
      ~PicklePump.open_file
      ~PicklePump.pre_finish
      ~PicklePump.process
      ~PicklePump.require
      ~PicklePump.rewind_file
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~PicklePump.name
   
   